chkelastic
==========

A command line tool to assert ElasticSearch index and document integrity.

Installation
------------

You will need Python 3.6+ installed in your host machine.

```
$ pip install chkelastic
```

Usage
-----

For more information about the available commands run

```
$ chkelastic -h
```


About
-----

During an ElasticSearch migration, a tool like this felt useful to have in order to elevate confidence that operations were being correctly applied from the old to the new cluster.
